@@ -68,7 +68,7 @@ def post_many_flows_to_database(dataset: pd.DataFrame, access_token: str, verbos
             print("Status Code: {}, {}.".format(response.status_code, response.text))
 
 
-def get_portfolio_weights(dataset: pd.DataFrame, access_token: str, verbose: bool = True):
+def get_portfolio_weights(dataset: pd.DataFrame, schema: str, access_token: str, verbose: bool = True):
     """
     This function collects the portfolio weights for the head name portfolio. The function firstly
     checks that each of the arguments are of the expected type, followed by creating a json packet
@@ -76,22 +76,22 @@ def get_portfolio_weights(dataset: pd.DataFrame, access_token: str, verbose: boo
     made, after which, the portfolio weights are returned.
 
     :param dataset: a Pandas DataFrame containing the data to get the weights for. (pd.DataFrame)
+    :param schema: the portfolio schema to be considered. (str)
     :param access_token: the access token of the user, must be an active access token. (str)
     :param verbose: determines if status is printed. Default=True. (bool)
     :return: outcome: a Pandas DataFrame containing the data with new portfolio weights. (pd.DataFrame)
     """
     if not isinstance(dataset, pd.DataFrame):
         raise TypeError("The 'dataset' argument must be a Pandas DataFrame.")
-    if not isinstance(access_token, str):
-        raise TypeError("The 'access_token' argument must be a string type.")
+    if not all(isinstance(v, str) for v in [schema, access_token]):
+        raise TypeError("The 'schema' and 'access_token' arguments must be string types.")
     dict_list = dataset.to_json(orient='records')
-    url = "https://www.samsonrockapis.com/forecast_flows&portfolio_weights"
-    payload = {"forecast_flows": dict_list}
+    url = "https://www.samsonrockapis.com/forecast_flows&portfolio_weights&weight_schema={}".format(schema)
     header = {'Authorization': 'Bearer ' + access_token}
-    response = requests.get(url, headers=header, params=payload)
+    response = requests.get(url, headers=header, data=dict_list)
     if response.status_code in [200, 201, 202, 203, 204]:
         if verbose:
-            print("Status Code: {}, data posted to date table.".format(response.status_code))
+            print("Status Code: {}, portfolio weights calculates.".format(response.status_code))
         return pd.read_json(response.text)
     elif response.status_code in [401, 403]:
         if verbose:
